( cd bin ; rm -rf tar-1.16 )
( cd bin ; ln -sf tar tar-1.16 )
( cd usr/bin ; rm -rf tar )
( cd usr/bin ; ln -sf /bin/tar tar )
( cd etc ; rm -rf rmt )
( cd etc ; ln -sf /usr/libexec/rmt rmt )
( cd sbin ; rm -rf rmt )
( cd sbin ; ln -sf /usr/libexec/rmt rmt )
